@@ -12,7 +12,14 @@ MAX_AGE: int = 31 * 24 * 60 * 60  # a month in seconds
 
 
 def validate_config(config):
-    pass
+    mandatory_keys = {'uri', 'client_id', 'idp', 'redirect_uri'}
+
+    for _cookie_config, _cookie_config_data in config.items():
+        if not mandatory_keys.issubset(set(_cookie_config_data)):
+            raise ValueError(
+                f'Each entry must contain the following keys: {mandatory_keys}.'
+                f' Config "{_cookie_config}" is missing {mandatory_keys - set(_cookie_config_data)}.'
+            )
 
 
 def _get_cookie_configs(config):
